%%%  Date : December 16, 2003
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%
%%%
%%%  LaTeX' style for the 2007 CCToMM Symposium on Mechanisms, Machines, and
%%%  Mechatronics (2007 CCToMM M3)
%%%
%%%  File name : cctomm2007.cls
%%%
%%%  By : Boris Mayer St-Onge -- boris@gmc.ulaval.ca -- http://wwwrobot.gmc.ulaval.ca
%%%  Date : December 16, 2003
%%%
%%%  Modified by: Juan A. Carretero -- juan.carretero@unb.ca ---
%%%  Date : December 19, 2005
%%%
%%%  Modified by: M. John D. Hayes -- jhayes@mae.carleton.ca ---
%%%  Date : February 1, 2007
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{cctomm2007}[2007/02/01 2007 CCToMM M3 LaTeX class]

%%%  Load the standard class article, with the transfert of options
%%%\PassOptionsToClass{twocolumn,10pt}{article}
\PassOptionsToClass{10pt}{article}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions

\LoadClass{article}


\RequirePackage{times}                  % Loads the Times-Roman Fonts
\RequirePackage{ifthen}                 % Loads the command \ifthenelse
\usepackage[latin1]{inputenc}           % To use accentuated words
\usepackage[francais,english]{babel}    % For multiple language
\usepackage{setspace}
\usepackage[dvips]{graphics}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%
%%%  FONT DEFINITIONS
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%
%%%  Font Definitions (see The LaTeX Companion chapter 7 -- p.173 and 192 for
%%%  instance --- and section 28 --- question 28.2 and 28.3 for instance ---
%%%  of the fr.comp.text.tex FAQ (http://www.grappa.univ-lille3.fr/FAQ-LaTeX)).
%%%
%%% \DeclareFixedFont{\CodelineFont}{\encodingdefault}{\familydefault}
%%%     {\seriesdefault}{\shapedefault}{size}
%%%
%%%  Explication:
%%%  + {\CodelineFont} name of the font created
%%%  + {\encodingdefault} Encoding if the font, which is usually OT1.  See Table
%%%     7.12 on page 192 and question 28.1 and 28.2 in the FAQ.
%%%  + {\familydefault} Family of the font, which is cmr by default.  For times
%%%     package, the default is ptm (see file /texmf/tex/latex/psnfss/
%%%     times.sty).  See table 7.3 on page 173 and question 28.2 in the
%%%     FAQ.
%%%  + {\seriesdefault} Series of the font, which is m by default.  Other value
%%%     are a combinaison of "weight" and "width".  See table 7.10 on
%%%     page 190 and question 28.2 in the FAQ.
%%%  + {\shapedefault} Shape of the font, which is n by default.  Other value
%%%     can be it, sl, sc, ui and ol.  See table 7.11 on page 191 and
%%%     question 28.2 in the FAQ.
%%%  + {size} Size of the font, which is 10 by default.  Two values can be
%%%     specified, one for the size and one for the baseline (space
%%%     between 2 lines).
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% These are specific fonts used in the file.

% For title : Times Roman, 12pt, boldface
%\DeclareFixedFont{\ttlfnt}{OT1}{ptm}{b}{n}{18}
\DeclareFixedFont{\ttlfnt}{\encodingdefault}{\familydefault}{\bfdefault}%
    {\shapedefault}{12}

%% For authors : Times Roman, 12pt
%\DeclareFixedFont{\autfnt}{OT1}{ptm}{m}{n}{12}
\DeclareFixedFont{\autfnt}{\encodingdefault}{\familydefault}{\seriesdefault}%
    {\shapedefault}{12}

%% For affiliations : Times Roman, 10pt, italic
%\DeclareFixedFont{\afffnt}{OT1}{ptm}{m}{it}{10}
\DeclareFixedFont{\afffnt}{\encodingdefault}{\familydefault}{\seriesdefault}%
    {\itdefault}{10}

%% For first header : Times Roman, 12pt, boldface and smallcaps
%\DeclareFixedFont{\hofnt}{OT1}{ptm}{b}{sc}{12}
\DeclareFixedFont{\hofnt}{\encodingdefault}{\familydefault}{\bfdefault}% [JACG]
    {\scdefault}{12}

%% For second header : Times Roman, 12pt
%\DeclareFixedFont{\htfnt}{OT1}{ptm}{b}{n}{12}
\DeclareFixedFont{\htfnt}{\encodingdefault}{\familydefault}{\seriesdefault}% [JACG] Changed from \bfdefault to \seriesdefault
    {\shapedefault}{12}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%
%%%  PAGE STYLE
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% Use 8.5 in x 11 in paper, with text of 6in x 9in.  Margins are 1.25in for
%% side and 1in for top/bottom.  Columns size is 2.75in with 0.50in between.
\usepackage{vmargin}
\setpapersize{USletter}

%% Syntax review
%% \setmargins{leftmargins}{topmargin}{textwidth}{textheight}%
%%    {headheight}{headsep}{footheight}{footskip}
%%
%% leftmargins is the left margins
%% topmargin is the top margins
%% textwidth is the text width
%% textheight is the text height
%% headheight fix the header height
%% headsep fix the distance between the header and the text
%% footheight fix the footer height
%% footskip fix the distance between the footer and the text
%\setmargins{1.25in}{1in}{6in}{9in}{0in}{0in}{0in}{2\baselineskip}
\setmargins{25.4mm}{25.4mm}{165.1mm}{215.9mm}{0in}{0in}{5mm}{1.5\baselineskip}

%% Space of 0.50in between column
\setlength{\columnsep}{0.50in}

%% 5 mm indentation
\setlength{\parindent}{5mm}

%% Redefine the page style "plain".  No header and for footer :
%%  - CCToMM identification line (CCToMM M3 2007) flush left, 10pt Times Roman (default)
%%  - page number flush left, boldface, 10pt Times Roman (default)
\renewcommand{\ps@plain}{%
  \renewcommand{\@oddhead}{}%
  \renewcommand{\@evenhead}{}%
%  \renewcommand{\@evenfoot}{{\rule[13pt]{\linewidth}{0.2mm}} \newline \hspace{8cm} \centering  \emph{\thepage}}%

  \renewcommand{\@evenfoot}{\parbox{\textwidth}{\rule{\linewidth}{0.2mm} \newline
                     \vspace{-1.8em} \small \begin{flushright}\emph{\thepage}\end{flushright}}}%


%  \renewcommand{\@evenfoot}{\parbox{\textwidth}{\rule{\linewidth}{0.2mm} \newline
%                     \small \hspace{8cm} \centering \emph{\thepage}}}%


%  \renewcommand{\@evenfoot}{}
  \renewcommand{\@oddfoot}{\@evenfoot}%
}
\pagestyle{plain}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%
%%%  SECTIONING
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%
%%%  The syntax for the definition of section is (see LaTeX Companion p.24)
%%%
%%%   \renewcommand\section{\@startsection {section}{1}{\z@}%
%%%        {-3.5ex \@plus -1ex \@minus -.2ex}%
%%%        {2.3ex \@plus.2ex}%
%%%        {\reset@font\Large\bfseries}}
%%%
%%%  Explication :
%%%  + {section} name of the sectioning command.
%%%  + {1} Number denoting the depth level of the sectioning command.
%%%  + {\z@} Indentation of the heading (zero).
%%%  + {-3.5ex \@plus -1ex \@minus -.2ex} defined the space to be left
%%%     in front of the heading.
%%%  + {2.3ex \@plus.2ex} defined the space to be left following
%%%     a heading.  If this number is under zero, the
%%%     space is horizontal, in order to have horizontal title
%%%     like :
%%%     Section title.   Here is the text of my section ...
%%%  + \@plus and \@minus allow to stretch and shrink component.
%%%  + {\reset@font\Large\bfseries} Style of the heading text.
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% Headings #1: Times boldface, 12pt, small caps (see \hofnt) and flush left.
%% Space of 12pt from bottom of preceeding text and 6pt after.
\renewcommand{\section}{\@startsection
  {section}%    % the name
  {1}%          % the level
  {0mm}%        % the indent
  {-8pt}%      % the beforeskip
  {5pt}%        % the afterskip
  {\hofnt}%     % the style
}%

%% Headings #2: Times, 12pt (see \htfnt) and flush left.
%% Space of 8pt from bottom of preceeding text and 6pt after.
\renewcommand{\subsection}{\@startsection
  {subsection}%     % the name
  {2}%              % the level
  {0mm}%            % the indent
  {-8pt}%           % the beforeskip
  {6pt}%            % the afterskip
  {\hspace{-5mm} \htfnt \underline}%         % the style
}%

%% Headings #3: Times boldface, 12pt (see \hofnt) and flush left.
%% Space of 8pt from bottom of preceeding text and 6pt after.
\renewcommand{\subsubsection}{\@startsection
  {subsubsection}%     % the name
  {2}%              % the level
  {0mm}%            % the indent
  {-6pt}%           % the beforeskip
  {2pt}%            % the afterskip
  {\htfnt}%         % the style
}%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%
%%%  TITLE HEADER
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% Add a field for affiliation and multiple author
\def\AuthorI#1{\gdef\@AuthorI{#1}}
\def\AuthorII#1{\gdef\@AuthorII{#1}}
\def\AuthorIII#1{\gdef\@AuthorIII{#1}}
\def\AuthorIV#1{\gdef\@AuthorIV{#1}}
\def\AuthorV#1{\gdef\@AuthorV{#1}}
\def\AuthorVI#1{\gdef\@AuthorVI{#1}}
\def\AuthorVII#1{\gdef\@AuthorVII{#1}}
\def\AffiliationI#1{\gdef\@AffiliationI{#1}}
\def\AffiliationII#1{\gdef\@AffiliationII{#1}}
\def\AffiliationIII#1{\gdef\@AffiliationIII{#1}}
\def\AffiliationIV#1{\gdef\@AffiliationIV{#1}}
\def\AffiliationV#1{\gdef\@AffiliationV{#1}}
\def\AffiliationVI#1{\gdef\@AffiliationVI{#1}}
\def\AffiliationVII#1{\gdef\@AffiliationVII{#1}}

%% Empty field by default
\AuthorI{}
\AuthorII{}
\AuthorIII{}
\AuthorIV{}
\AuthorV{}
\AuthorVI{}
\AuthorVII{}
\AffiliationI{}
\AffiliationII{}
\AffiliationIII{}
\AffiliationIV{}
\AffiliationV{}
\AffiliationVI{}
\AffiliationVII{}

%% For internal use
\newcounter{nbAffiliation}

%%   Leave space of 18 pt before the title
%% - Title are in 18pt, boldface (see \ttlfnt) and centered.
%%   Leave space of 20pt after the title.
%% - Author are in 12pt (see \autfnt) and centered.
%%   Leave space of 12pt after the author.
%% - The affiliation are in 10pt, italic (see \afffnt) and centered.
%%
%% - The affiliation field has been added

\def\@maketitle{%
%% Write the title and the authors with their affiliations
\newpage%
\null%
\begin{center}%
  \vskip 18pt%
  {\ttlfnt\@title}%
  \vskip 20pt%
    %% We put label over the authors
    {\stepcounter{nbAffiliation}
      %% Check if a second author is defined
      \ifthenelse{\equal{\@AuthorII}{}}{
        %% No second author, write only the first one.
        \autfnt\@AuthorI%
      }{%
        %% One have a second author, write the first one with commas.
        \stepcounter{nbAffiliation}
        \autfnt\@AuthorI\footnotemark~,%
        %% Check if a third author is defined
        \ifthenelse{\equal{\@AuthorIII}{}}{
          %% No third author, write the second one without commas.
          \hspace*{5mm}\autfnt\@AuthorII\footnotemark%
        }{%
          %% One have a third author, write the second one with commas.
          \stepcounter{nbAffiliation}
          \hspace*{5mm}\autfnt\@AuthorII\footnotemark~,%
          %% Check if a fourth author is defined
          \ifthenelse{\equal{\@AuthorIV}{}}{
            %% No fourth author, write the third one without commas.
            \hspace*{5mm}\autfnt\@AuthorIII\footnotemark%
          }{%
            %% One have a fourth author, write the third one with commas.
            \stepcounter{nbAffiliation}
            \hspace*{5mm}\autfnt\@AuthorIII\footnotemark~,%
            %% Check if a fifth author is defined
            \ifthenelse{\equal{\@AuthorV}{}}{
              %% No fifth author, write the fourth one without commas.
              \hspace*{5mm}\autfnt\@AuthorIV\footnotemark%
            }{%
              %% One have a fifth author, write the fourth one with commas.
              \stepcounter{nbAffiliation}
              \hspace*{5mm}\autfnt\@AuthorIV\footnotemark~,%
              %% Check if a sixth author is defined
              \ifthenelse{\equal{\@AuthorVI}{}}{
                %% No sixth author, write the fifth one without commas.
                \hspace*{5mm}\autfnt\@AuthorV\footnotemark%
              }{%
                %% One have a sixth author, write the fifth one with commas.
                \stepcounter{nbAffiliation}
                \hspace*{5mm}\autfnt\@AuthorV\footnotemark~,%
                %% Check if a seventh author is defined
                \ifthenelse{\equal{\@AuthorVII}{}}{
                  %% No seventh author, write the sixth one without commas.
                  \hspace*{5mm}\autfnt\@AuthorVI\footnotemark%
                }{%
                  %% One have a seventh author, the sixth one with commas and the seventh one.
                  \stepcounter{nbAffiliation}
                  \hspace*{5mm}\autfnt\@AuthorVI\footnotemark~,\hspace*{5mm}\autfnt\@AuthorVII\footnotemark%
                }%
              }%
            }%
          }%
        }%
      }%
    }%
    \vskip 1pt% %[JACG]
    %% Write the affiliation
    \setcounter{footnote}{0}
    { \ifnum\value{nbAffiliation}>1 \footnotemark~~\afffnt\@AffiliationI \vskip 12pt\footnotemark~~\afffnt\@AffiliationII
        \ifnum\value{nbAffiliation}>2 \vskip 12pt\footnotemark~~\afffnt\@AffiliationIII
          \ifnum\value{nbAffiliation}>3 \vskip 12pt\footnotemark~~\afffnt\@AffiliationIV
            \ifnum\value{nbAffiliation}>4 \vskip 12pt\footnotemark~~\afffnt\@AffiliationV
              \ifnum\value{nbAffiliation}>5 \vskip 12pt\footnotemark~~\afffnt\@AffiliationVI
                \ifnum\value{nbAffiliation}>6 \vskip 12pt\footnotemark~~\afffnt\@AffiliationVII
                \fi
              \fi
            \fi
          \fi
        \fi
      \fi} \par%
\end{center}%
% By default, one line is automaticaly added with the beginning of the 2 column format.
% So do not need to put a vskip.
%\vskip 12pt%
}

%% Copy the definition of maketitle to make label as number and to set
%% the counter of footnote
\renewcommand\maketitle{\par
  \begingroup
    %% Set the label to number instead of symbol
    %\renewcommand\thefootnote{\@fnsymbol\c@footnote}%
    \renewcommand\thefootnote{\@arabic\c@footnote}%
    \def\@makefnmark{\rlap{\@textsuperscript{\normalfont\@thefnmark}}}%
    \long\def\@makefntext##1{\parindent 1em\noindent
            \hb@xt@1.8em{%
                \hss\@textsuperscript{\normalfont\@thefnmark}}##1}%
    \if@twocolumn
      \ifnum \col@number=\@ne
        \@maketitle
      \else
        \twocolumn[\@maketitle]%
      \fi
    \else
      \newpage
      \global\@topnum\z@   % Prevents figures from going at top of page.
      \@maketitle
    \fi
    \thispagestyle{plain}\@thanks
  \endgroup
  %% Set counter to the number of affiliation
  %\setcounter{footnote}{0}%
  \setcounter{footnote}{\value{nbAffiliation}}
  \global\let\thanks\relax
  \global\let\maketitle\relax
  \global\let\@maketitle\relax
  \global\let\@thanks\@empty
  \global\let\@author\@empty
  \global\let\@date\@empty
  \global\let\@title\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\and\relax
}

%% Set the footnote counter to the new value, ie the number of affiliation.
\setcounter{footnote}{\value{nbAffiliation}}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%
%%%  TABLE AND FIGURE
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% Caption type: Times 10pt (default).  For figure, the caption
%% should be centered below the figure.  Then, use the command \caption after the
%% command \includegraphics.  For table, the caption should be centered above the
%% table.  Then, use the command \caption before the environment tabular.

\renewenvironment{abstract}{\hspace{-5mm}\rule{\linewidth}{0.2mm}}{}
\AtBeginDocument{\renewcommand\refname{\iflanguage{english}{REFERENCES}{R\'{E}F\'{E}RENCES}}}




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%
%%%   HOW TO USE IT
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%
% \documentclass{cctomm2007}
%
% \begin{document}
%
% %\selectlanguage{francais}    %% Uncomment for francais
%
% \twocolumn[
% \title{The title of your csme paper goes here}
%
% %% You can add up to 7 differents authors/affiliation (\AuthorI, \AuthorII,
% %% \AuthorIII, etc. and \AffiliationI, \AffiliationII, \AffiliationIII, etc.).
%
% \AuthorI{First author}
% \AffiliationI{Affiliation of first author}
%
% \AuthorII{Second author}
% \AffiliationII{Affiliation of second author}
%
% \maketitle
%
% \begin{abstract}
% Text of your abstract ...
% \end{abstract}
% \vskip\baselineskip]
%
% \section{First section}
%
% Text of your paper ...
%
% \end{document}
%
